@@ -18,19 +18,22 @@
  **/
 
 #include "kdesktopfileactions.h"
+
+#include "config-kio.h"
+
 #include "krun.h"
 #include "kautomount.h"
 #include <kmessageboxwrapper.h>
 #include <kdirnotify.h>
 #include <kmountpoint.h>
 
-#include <kglobal.h>
 #include <kstandarddirs.h>
 #include <kdesktopfile.h>
 #include <kconfiggroup.h>
 #include <klocale.h>
-#include "kservice.h"
+#include <kservice.h>
 
+#ifndef KIO_NO_SOLID
 //Solid
 #include <solid/devicenotifier.h>
 #include <solid/device.h>
@@ -40,6 +43,7 @@
 #include <solid/opticaldrive.h>
 #include <solid/opticaldisc.h>
 #include <solid/block.h>
+#endif
 
 enum BuiltinServiceType { ST_MOUNT = 0x0E1B05B0, ST_UNMOUNT = 0x0E1B05B1 }; // random numbers
 
@@ -54,11 +58,11 @@ bool KDesktopFileActions::run( const KUrl& u, bool _is_local )
     if ( !_is_local )
         return false;
 
-    KDesktopFile cfg( u.path() );
+    KDesktopFile cfg(u.toLocalFile());
     if ( !cfg.desktopGroup().hasKey("Type") )
     {
         QString tmp = i18n("The desktop entry file %1 "
-                           "has no Type=... entry.", u.path() );
+                           "has no Type=... entry.", u.toLocalFile() );
         KMessageBoxWrapper::error( 0, tmp);
         return false;
     }
@@ -87,7 +91,7 @@ static bool runFSDevice( const KUrl& _url, const KDesktopFile &cfg )
 
     if ( dev.isEmpty() )
     {
-        QString tmp = i18n("The desktop entry file\n%1\nis of type FSDevice but has no Dev=... entry.",  _url.path() );
+        QString tmp = i18n("The desktop entry file\n%1\nis of type FSDevice but has no Dev=... entry.",  _url.toLocalFile() );
         KMessageBoxWrapper::error( 0, tmp);
         return retval;
     }
@@ -106,7 +110,7 @@ static bool runFSDevice( const KUrl& _url, const KDesktopFile &cfg )
             fstype.clear();
         QString point = cg.readEntry( "MountPoint" );
 #ifndef Q_WS_WIN
-        (void) new KAutoMount( ro, fstype.toLatin1(), dev, point, _url.path() );
+        (void) new KAutoMount( ro, fstype.toLatin1(), dev, point, _url.toLocalFile() );
 #endif
         retval = false;
     }
@@ -176,6 +180,7 @@ QList<KServiceAction> KDesktopFileActions::builtinServices( const KUrl& _url )
             offerMount = true;
         }
     }
+#ifndef KIO_NO_SOLID
     else { // url to device
         Solid::Predicate predicate(Solid::DeviceInterface::Block, "device", _url.toLocalFile());
         const QList<Solid::Device> devList = Solid::Device::listFromQuery(predicate, QString());
@@ -196,6 +201,7 @@ QList<KServiceAction> KDesktopFileActions::builtinServices( const KUrl& _url )
             offerMount = true;
         }
     }
+#endif
 
     if (offerMount) {
         KServiceAction mount("mount", i18n("Mount"), QString(), QString(), false);
@@ -325,6 +331,7 @@ void KDesktopFileActions::executeService( const KUrl::List& urls, const KService
 #endif
             }
         }
+#ifndef KIO_NO_SOLID
         else { // path to device
             Solid::Predicate predicate(Solid::DeviceInterface::Block, "device", path);
             const QList<Solid::Device> devList = Solid::Device::listFromQuery(predicate, QString());
@@ -355,8 +362,9 @@ void KDesktopFileActions::executeService( const KUrl::List& urls, const KService
                 kDebug(7000) << "Device" << path << "not found";
             }
         }
+#endif
     } else {
-        kDebug() << action.name() << "first url's path=" << urls.first().path() << "exec=" << action.exec();
+        kDebug() << action.name() << "first url's path=" << urls.first().toLocalFile() << "exec=" << action.exec();
         KRun::run( action.exec(), urls, 0, action.text(), action.icon());
         // The action may update the desktop file. Example: eject unmounts (#5129).
         org::kde::KDirNotify::emitFilesChanged( urls.toStringList() );
